import {isAndroid, isIOS} from "react-device-detect";

export * from './translate'

export const MAINNET_RPC_URL = 'https://api-mainnet-beta.renec.foundation:8899'
export const MAINNET_WSS_URL = 'wss://api-mainnet-beta.renec.foundation:8900'
export const TESTNET_RPC_URL = 'https://api-testnet.renec.foundation:8899'
export const TESTNET_WSS_URL = 'wss://api-testnet.renec.foundation:8900'
export const EXPLORER_URL = 'https://explorer.renec.foundation'

declare global {
  interface Window {
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    Cypress: any;
    demon: {
      sol: object;
    }
  }
}

export const getNetworkUrls = (isMainnet: boolean) => isMainnet
  ? { rpc: MAINNET_RPC_URL, wss: MAINNET_WSS_URL }
  : { rpc: TESTNET_RPC_URL, wss: TESTNET_WSS_URL }

export const isRunningInCypress = typeof window !== 'undefined' && window.Cypress !== undefined

export const isDemonWalletDetected = () => window.demon?.sol || window.Cypress

export const getDemonWalletUrl = () => {
  if (isAndroid || isIOS) {
    return `https://demon.renec.foundation/#/connect?dapp=${window.location.origin}`
  }
  return "https://chrome.google.com/webstore/detail/demon-wallet/mdjmfdffdcmnoblignmgpommbefadffd"
}

export const handleRedirectIfDemonNotInstalled = () => {
  const url = getDemonWalletUrl()
  if (isIOS) {
    window.location.href = url
  } else {
    window.open(url)
  }
}
